@@ -3,8 +3,7 @@ import logging
 from collections import defaultdict
 
 import boto3
-from elasticsearch import Elasticsearch, RequestsHttpConnection
-from elasticsearch.helpers import parallel_bulk
+from elasticsearch import Elasticsearch, helpers, RequestsHttpConnection
 from elasticsearch_dsl import Q, Search
 from elasticsearch_dsl.query import Bool
 from requests_aws4auth import AWS4Auth
@@ -22,9 +21,13 @@ from .settings import (
     ELASTICSEARCH_CHUNK_SIZE,
     ELASTICSEARCH_CLIENT_CERT,
     ELASTICSEARCH_CLIENT_KEY,
+    ELASTICSEARCH_INITIAL_BACKOFF,
+    ELASTICSEARCH_MAX_BACKOFF,
     ELASTICSEARCH_MAX_CHUNK_BYTES,
+    ELASTICSEARCH_MAX_RETRIES,
     ELASTICSEARCH_QUEUE_SIZE,
     ELASTICSEARCH_SSL_SHOW_WARN,
+    ELASTICSEARCH_STREAMING_BULK,
     ELASTICSEARCH_THREAD_COUNT,
     ELASTICSEARCH_TIMEOUT,
     ELASTICSEARCH_USE_SSL,
@@ -48,20 +51,20 @@ class ElasticHelper(object):
         url = get_elasticsearch_url()
         self.__es = get_elasticsearch_client(url)
         self.version = list(
-            map(int, self.__es.info()['version']['number'].split('.'))
+            map(int, self.__es.info()["version"]["number"].split("."))
         )
 
-    def teardown(self, index):
+    def teardown(self, index: str) -> None:
         """
         Teardown the Elasticsearch index.
 
         :arg index: index (or list of indices) to read documents from
         """
         try:
-            logger.debug(f'Deleting index {index}')
+            logger.debug(f"Deleting index {index}")
             self.__es.indices.delete(index=index, ignore=[400, 404])
         except Exception as e:
-            logger.exception(f'Exception {e}')
+            logger.exception(f"Exception {e}")
             raise
 
     def bulk(
@@ -72,24 +75,49 @@ class ElasticHelper(object):
         max_chunk_bytes=None,
         queue_size=None,
         thread_count=None,
+        refresh=False,
+        max_retries=None,
+        initial_backoff=None,
+        max_backoff=None,
     ):
         """Bulk index, update, delete docs to Elasticsearch."""
         chunk_size = chunk_size or ELASTICSEARCH_CHUNK_SIZE
         max_chunk_bytes = max_chunk_bytes or ELASTICSEARCH_MAX_CHUNK_BYTES
         thread_count = thread_count or ELASTICSEARCH_THREAD_COUNT
         queue_size = queue_size or ELASTICSEARCH_QUEUE_SIZE
+        # max_retries, initial_backoff & max_backoff are only applicable when
+        # streaming bulk is in use
+        max_retries = max_retries or ELASTICSEARCH_MAX_RETRIES
+        initial_backoff = initial_backoff or ELASTICSEARCH_INITIAL_BACKOFF
+        max_backoff = max_backoff or ELASTICSEARCH_MAX_BACKOFF
 
-        for _ in parallel_bulk(
-            self.__es,
-            docs,
-            index=index,
-            thread_count=thread_count,
-            chunk_size=chunk_size,
-            max_chunk_bytes=max_chunk_bytes,
-            queue_size=queue_size,
-            refresh=False,
-        ):
-            pass
+        if ELASTICSEARCH_STREAMING_BULK:
+            for _ in helpers.streaming_bulk(
+                self.__es,
+                docs,
+                index=index,
+                chunk_size=chunk_size,
+                max_chunk_bytes=max_chunk_bytes,
+                max_retries=max_retries,
+                max_backoff=max_backoff,
+                initial_backoff=initial_backoff,
+                refresh=refresh,
+            ):
+                pass
+        else:
+            # parallel bulk consumes more memory and is also more likely
+            # to result in 429 errors.
+            for _ in helpers.parallel_bulk(
+                self.__es,
+                docs,
+                index=index,
+                thread_count=thread_count,
+                chunk_size=chunk_size,
+                max_chunk_bytes=max_chunk_bytes,
+                queue_size=queue_size,
+                refresh=refresh,
+            ):
+                pass
 
     def refresh(self, indices):
         """Refresh the Elasticsearch index."""
@@ -103,26 +131,29 @@ class ElasticHelper(object):
 
         fields = {
             'id': [1, 2],
-            'uid': ['a002', 'a009']
+            'uid': ['a002', 'a009'],
         }
         """
         fields = fields or {}
         search = Search(using=self.__es, index=index)
         # explicitly exclude all fields since we only need the doc _id
-        search = search.source(excludes=['*'])
+        search = search.source(excludes=["*"])
         for key, values in fields.items():
             search = search.query(
                 Bool(
                     filter=[
-                        Q('terms', **{f'{META}.{table}.{key}': values}) |
-                        Q('terms', **{f'{META}.{table}.{key}.keyword': values})
+                        Q("terms", **{f"{META}.{table}.{key}": values})
+                        | Q(
+                            "terms",
+                            **{f"{META}.{table}.{key}.keyword": values},
+                        )
                     ]
                 )
             )
         for hit in search.scan():
             yield hit.meta.id
 
-    def search(self, index, body):
+    def search(self, index: str, body: dict):
         """
         Search in Elasticsearch.
 
@@ -137,13 +168,7 @@ class ElasticHelper(object):
         if not self.__es.indices.exists(index):
 
             if setting:
-                body.update(
-                    **{
-                        'settings': {
-                            'index': setting
-                        }
-                    }
-                )
+                body.update(**{"settings": {"index": setting}})
 
             mapping = self._build_mapping(node, routing)
             if mapping:
@@ -158,13 +183,13 @@ class ElasticHelper(object):
                 raise
 
             # check the response of the request
-            logger.debug(f'create index response {response}')
+            logger.debug(f"create index response {response}")
             # check the result of the mapping on the index
             logger.debug(
-                f'created mapping: {self.__es.indices.get_mapping(index)}'
+                f"created mapping: {self.__es.indices.get_mapping(index)}"
             )
             logger.debug(
-                f'created setting: {self.__es.indices.get_settings(index)}'
+                f"created setting: {self.__es.indices.get_settings(index)}"
             )
 
     def _build_mapping(self, root, routing):
@@ -172,68 +197,63 @@ class ElasticHelper(object):
 
         for node in traverse_post_order(root):
 
-            rename = node.transform.get('rename', {})
-            mapping = node.transform.get('mapping', {})
+            rename = node.transform.get("rename", {})
+            mapping = node.transform.get("mapping", {})
 
             for key, value in mapping.items():
                 column = rename.get(key, key)
-                column_type = mapping[column]['type']
+                column_type = mapping[column]["type"]
                 if column_type not in ELASTICSEARCH_TYPES:
                     raise RuntimeError(
-                        f'Invalid Elasticsearch type {column_type}'
+                        f"Invalid Elasticsearch type {column_type}"
                     )
 
-                if 'properties' not in node._mapping:
-                    node._mapping['properties'] = {}
-                node._mapping['properties'][column] = {
-                    'type': column_type
-                }
+                if "properties" not in node._mapping:
+                    node._mapping["properties"] = {}
+                node._mapping["properties"][column] = {"type": column_type}
 
                 for parameter, parameter_value in mapping[column].items():
-                    if parameter == 'type':
+                    if parameter == "type":
                         continue
 
                     if parameter not in ELASTICSEARCH_MAPPING_PARAMETERS:
                         raise RuntimeError(
-                            f'Invalid Elasticsearch mapping parameter '
-                            f'{parameter}'
+                            f"Invalid Elasticsearch mapping parameter "
+                            f"{parameter}"
                         )
 
-                    node._mapping['properties'][column][
+                    node._mapping["properties"][column][
                         parameter
                     ] = parameter_value
 
             if node.parent and node._mapping:
-                if 'properties' not in node.parent._mapping:
-                    node.parent._mapping['properties'] = {}
-                node.parent._mapping['properties'][node.label] = node._mapping
+                if "properties" not in node.parent._mapping:
+                    node.parent._mapping["properties"] = {}
+                node.parent._mapping["properties"][node.label] = node._mapping
 
         if routing:
-            root._mapping['_routing'] = {
-                'required': True
-            }
+            root._mapping["_routing"] = {"required": True}
 
         if root._mapping:
             if self.version[0] < 7:
-                root._mapping = {'_doc': root._mapping}
+                root._mapping = {"_doc": root._mapping}
 
             return dict(mappings=root._mapping)
 
 
-def get_elasticsearch_client(url):
+def get_elasticsearch_client(url: str) -> Elasticsearch:
 
     if ELASTICSEARCH_AWS_HOSTED:
         credentials = boto3.Session().get_credentials()
-        http_auth = AWS4Auth(
-            credentials.access_key,
-            credentials.secret_key,
-            ELASTICSEARCH_AWS_REGION,
-            'es',
-            session_token=credentials.token,
-        )
         return Elasticsearch(
-            hosts=[{'host': url, 'port': 443}],
-            http_auth=http_auth,
+            hosts=[url],
+            http_auth=AWS4Auth(
+                credentials.access_key,
+                credentials.secret_key,
+                ELASTICSEARCH_AWS_REGION,
+                "es",
+                session_token=credentials.token,
+            ),
             use_ssl=True,
             verify_certs=True,
             connection_class=RequestsHttpConnection,
