@@ -5,6 +5,7 @@ import sys
 import threading
 import time
 from datetime import timedelta
+from typing import Optional
 from urllib.parse import quote_plus
 
 from .exc import SchemaError
@@ -22,6 +23,7 @@ from .settings import (
     REDIS_DB,
     REDIS_HOST,
     REDIS_PORT,
+    REDIS_SCHEME,
     SCHEMA,
 )
 
@@ -34,15 +36,16 @@ def timeit(func):
         retval = func(*args, **kwargs)
         until = time.time()
         sys.stdout.write(
-            f'{func.__name__} ({args}, {kwargs}) {until-since} secs\n'
+            f"{func.__name__} ({args}, {kwargs}) {until-since} secs\n"
         )
         return retval
+
     return timed
 
 
 class Timer:
-    def __init__(self, message=None):
-        self._message = message or ''
+    def __init__(self, message: Optional[str] = None):
+        self._message = message or ""
 
     def __enter__(self):
         self.start = time.time()
@@ -52,54 +55,56 @@ class Timer:
         self.end = time.time()
         self.elapsed = self.end - self.start
         sys.stdout.write(
-            f'{self._message} {str(timedelta(seconds=self.elapsed))} '
-            f'({self.elapsed:2.2f} sec)\n'
+            f"{self._message} {str(timedelta(seconds=self.elapsed))} "
+            f"({self.elapsed:2.2f} sec)\n"
         )
 
 
-def show_settings(schema=None, params={}):
+def show_settings(schema: str = None, params: dict = {}) -> None:
     """Show configuration."""
-    logger.info('\033[4mSettings\033[0m:')
+    logger.info("\033[4mSettings\033[0m:")
     logger.info(f'{"Schema":<10s}: {schema or SCHEMA}')
-    logger.info('-' * 65)
-    logger.info('\033[4mPostgres\033[0m:')
+    logger.info("-" * 65)
+    logger.info("\033[4mPostgres\033[0m:")
     logger.info(
         f'URL: postgresql://{params.get("user", PG_USER)}:*****@'
         f'{params.get("host", PG_HOST)}:'
         f'{params.get("port", PG_PORT)}'
     )
-    logger.info('\033[4mElasticsearch\033[0m:')
+    logger.info("\033[4mElasticsearch\033[0m:")
     if ELASTICSEARCH_USER:
         logger.info(
-            f'URL: {ELASTICSEARCH_SCHEME}://{ELASTICSEARCH_USER}:*****@'
-            f'{ELASTICSEARCH_HOST}:{ELASTICSEARCH_PORT}'
+            f"URL: {ELASTICSEARCH_SCHEME}://{ELASTICSEARCH_USER}:*****@"
+            f"{ELASTICSEARCH_HOST}:{ELASTICSEARCH_PORT}"
         )
     else:
         logger.info(
-            f'URL: {ELASTICSEARCH_SCHEME}://'
-            f'{ELASTICSEARCH_HOST}:{ELASTICSEARCH_PORT}'
+            f"URL: {ELASTICSEARCH_SCHEME}://"
+            f"{ELASTICSEARCH_HOST}:{ELASTICSEARCH_PORT}"
         )
-    logger.info('\033[4mRedis\033[0m:')
-    logger.info(f'URL: redis://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}')
-    logger.info('-' * 65)
+    logger.info("\033[4mRedis\033[0m:")
+    logger.info(f"URL: {REDIS_SCHEME}://{REDIS_HOST}:{REDIS_PORT}/{REDIS_DB}")
+    logger.info("-" * 65)
 
 
 def threaded(fn):
     """Decorator for threaded code execution."""
+
     def wrapper(*args, **kwargs):
         thread = threading.Thread(target=fn, args=args, kwargs=kwargs)
         thread.start()
         return thread
+
     return wrapper
 
 
 def get_elasticsearch_url(
-    scheme=None,
-    user=None,
-    host=None,
-    password=None,
-    port=None,
-):
+    scheme: Optional[str] = None,
+    user: Optional[str] = None,
+    host: Optional[str] = None,
+    password: Optional[str] = None,
+    port: Optional[int] = None,
+) -> str:
     """
     Return the URL to connect to Elasticsearch.
     """
@@ -109,18 +114,18 @@ def get_elasticsearch_url(
     user = user or ELASTICSEARCH_USER
     password = password or ELASTICSEARCH_PASSWORD
     if user:
-        return f'{scheme}://{user}:{quote_plus(password)}@{host}:{port}'
-    logger.debug('Connecting to Elasticsearch without authentication.')
-    return f'{scheme}://{host}:{port}'
+        return f"{scheme}://{user}:{quote_plus(password)}@{host}:{port}"
+    logger.debug("Connecting to Elasticsearch without authentication.")
+    return f"{scheme}://{host}:{port}"
 
 
 def get_postgres_url(
-    database,
-    user=None,
-    host=None,
-    password=None,
-    port=None,
-):
+    database: str,
+    user: Optional[str] = None,
+    host: Optional[str] = None,
+    password: Optional[str] = None,
+    port: Optional[int] = None,
+) -> str:
     """
     Return the URL to connect to Postgres.
     """
@@ -128,13 +133,21 @@ def get_postgres_url(
     host = host or PG_HOST
     password = password or PG_PASSWORD
     port = port or PG_PORT
-    if password:
-        return f'postgresql://{user}:{quote_plus(password)}@{host}:{port}/{database}'
-    logger.debug('Connecting to Postgres without password.')
-    return f'postgresql://{user}@{host}:{port}/{database}'
+    if not password:
+        logger.debug("Connecting to Postgres without password.")
+        return f"postgresql://{user}@{host}:{port}/{database}"
+    return (
+        f"postgresql://{user}:{quote_plus(password)}@{host}:{port}/{database}"
+    )
 
 
-def get_redis_url(host=None, password=None, port=None, db=None):
+def get_redis_url(
+    scheme: Optional[str] = None,
+    host: Optional[str] = None,
+    password: Optional[str] = None,
+    port: Optional[int] = None,
+    db: Optional[str] = None,
+) -> str:
     """
     Return the URL to connect to Redis.
     """
@@ -142,22 +155,23 @@ def get_redis_url(host=None, password=None, port=None, db=None):
     password = password or REDIS_AUTH
     port = port or REDIS_PORT
     db = db or REDIS_DB
+    scheme = scheme or REDIS_SCHEME
     if password:
-        return f'redis://:{quote_plus(password)}@{host}:{port}/{db}'
-    logger.debug('Connecting to Redis without password.')
-    return f'redis://{host}:{port}/{db}'
+        return f"{scheme}://:{quote_plus(password)}@{host}:{port}/{db}"
+    logger.debug("Connecting to Redis without password.")
+    return f"{scheme}://{host}:{port}/{db}"
 
 
-def get_config(config=None):
+def get_config(config: Optional[str] = None) -> str:
     """
     Return the schema config for PGSync.
     """
     config = config or SCHEMA
     if not config:
         raise SchemaError(
-            'Schema config not set\n. '
-            'Set env SCHEMA=/path/to/schema.json or '
-            'provide args --config /path/to/schema.json'
+            "Schema config not set\n. "
+            "Set env SCHEMA=/path/to/schema.json or "
+            "provide args --config /path/to/schema.json"
         )
     if not os.path.exists(config):
         raise IOError(f'Schema config "{config}" not found')
