@@ -4,133 +4,100 @@ import pytest
 from pgsync.node import traverse_breadth_first, traverse_post_order, Tree
 
 
-@pytest.mark.usefixtures('table_creator')
+@pytest.mark.usefixtures("table_creator")
 class TestNode(object):
     """Node tests."""
 
-    @pytest.fixture(scope='function')
+    @pytest.fixture(scope="function")
     def nodes(self):
         return {
             "table": "book",
-            "columns": [
-                "isbn",
-                "title",
-                "description"
-            ],
+            "columns": ["isbn", "title", "description"],
             "children": [
                 {
                     "table": "publisher",
-                    "columns": [
-                        "name",
-                        "id"
-                    ],
+                    "columns": ["name", "id"],
                     "label": "publisher_label",
                     "relationship": {
                         "variant": "object",
-                        "type": "one_to_one"
+                        "type": "one_to_one",
                     },
-                    "children": [
-
-                    ],
-                    "transform": {
-                    }
+                    "children": [],
+                    "transform": {},
                 },
                 {
                     "table": "book_language",
-                    "columns": [
-                        "book_isbn",
-                        "language_id"
-                    ],
+                    "columns": ["book_isbn", "language_id"],
                     "label": "book_languages",
                     "relationship": {
                         "variant": "object",
-                        "type": "one_to_many"
-                    }
+                        "type": "one_to_many",
+                    },
                 },
                 {
                     "table": "author",
-                    "columns": [
-                        "id", "name"
-                    ],
+                    "columns": ["id", "name"],
                     "label": "authors",
                     "relationship": {
                         "type": "one_to_many",
                         "variant": "object",
-                        "through_tables": [
-                            "book_author"
-                        ]
+                        "through_tables": ["book_author"],
                     },
                     "children": [
                         {
                             "table": "city",
-                            "columns": [
-                                "name",
-                                "id"
-                            ],
+                            "columns": ["name", "id"],
                             "label": "city_label",
                             "relationship": {
                                 "variant": "object",
-                                "type": "one_to_one"
+                                "type": "one_to_one",
                             },
                             "children": [
                                 {
                                     "table": "country",
-                                    "columns": [
-                                        "name",
-                                        "id"
-                                    ],
+                                    "columns": ["name", "id"],
                                     "label": "country_label",
                                     "relationship": {
                                         "variant": "object",
-                                        "type": "one_to_one"
+                                        "type": "one_to_one",
                                     },
                                     "children": [
                                         {
                                             "table": "continent",
-                                            "columns": [
-                                                "name"
-                                            ],
+                                            "columns": ["name"],
                                             "label": "continent_label",
                                             "relationship": {
                                                 "variant": "object",
-                                                "type": "one_to_one"
-                                            }
+                                                "type": "one_to_one",
+                                            },
                                         }
-                                    ]
+                                    ],
                                 }
-                            ]
+                            ],
                         }
-                    ]
+                    ],
                 },
                 {
                     "table": "language",
                     "label": "languages",
-                    "columns": [
-                        "code"
-                    ],
+                    "columns": ["code"],
                     "relationship": {
                         "type": "one_to_many",
                         "variant": "scalar",
-                        "through_tables": [
-                            "book_language"
-                        ]
-                    }
+                        "through_tables": ["book_language"],
+                    },
                 },
                 {
                     "table": "subject",
                     "label": "subjects",
-                    "columns": [
-                        "name"
-                    ],
+                    "columns": ["name"],
                     "relationship": {
                         "type": "one_to_many",
                         "variant": "scalar",
-                        "through_tables": [
-                            "book_subject"
-                        ]
-                    }
-                }
-            ]
+                        "through_tables": ["book_subject"],
+                    },
+                },
+            ],
         }
 
     def test_traverse_breadth_first(self, sync, nodes):
@@ -139,23 +106,23 @@ class TestNode(object):
         root.display()
         for i, node in enumerate(traverse_breadth_first(root)):
             if i == 0:
-                assert node.table == 'book'
+                assert node.table == "book"
             if i == 1:
-                assert node.table == 'publisher'
+                assert node.table == "publisher"
             if i == 2:
-                assert node.table == 'book_language'
+                assert node.table == "book_language"
             if i == 3:
-                assert node.table == 'author'
+                assert node.table == "author"
             if i == 4:
-                assert node.table == 'language'
+                assert node.table == "language"
             if i == 5:
-                assert node.table == 'subject'
+                assert node.table == "subject"
             if i == 6:
-                assert node.table == 'city'
+                assert node.table == "city"
             if i == 7:
-                assert node.table == 'country'
+                assert node.table == "country"
             if i == 8:
-                assert node.table == 'continent'
+                assert node.table == "continent"
 
     def test_traverse_post_order(self, sync, nodes):
         tree = Tree(sync)
@@ -163,20 +130,20 @@ class TestNode(object):
         root.display()
         for i, node in enumerate(traverse_post_order(root)):
             if i == 0:
-                assert node.table == 'publisher'
+                assert node.table == "publisher"
             if i == 1:
-                assert node.table == 'book_language'
+                assert node.table == "book_language"
             if i == 2:
-                assert node.table == 'continent'
+                assert node.table == "continent"
             if i == 3:
-                assert node.table == 'country'
+                assert node.table == "country"
             if i == 4:
-                assert node.table == 'city'
+                assert node.table == "city"
             if i == 5:
-                assert node.table == 'author'
+                assert node.table == "author"
             if i == 6:
-                assert node.table == 'language'
+                assert node.table == "language"
             if i == 7:
-                assert node.table == 'subject'
+                assert node.table == "subject"
             if i == 8:
-                assert node.table == 'book'
+                assert node.table == "book"
